You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by fr...@apache.org on 2007/03/01 01:33:42 UTC

svn commit: r513084 [1/2] - in /incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo: impl/ model/ model/impl/

Author: frankb
Date: Wed Feb 28 16:33:41 2007
New Revision: 513084

URL: http://svn.apache.org/viewvc?view=rev&rev=513084
Log:
sdoModel.xsd should have been regened for TUSCANY-521

Modified:
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/AttributeImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ClassImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/DataTypeImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ReferenceImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/BaseDataGraphType.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/ModelFactory.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Property.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Type.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/BaseDataGraphTypeImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataGraphTypeImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataObjectImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelFactoryImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelsTypeImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/PropertyImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/TextTypeImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/TypeImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/TypesImpl.java
    incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/XSDTypeImpl.java

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/AttributeImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/AttributeImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/AttributeImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/AttributeImpl.java Wed Feb 28 16:33:41 2007
@@ -21,6 +21,7 @@
 
 import java.util.List;
 
+import org.apache.tuscany.sdo.impl.DataObjectBase.ChangeKind;
 import org.apache.tuscany.sdo.util.BasicSequence;
 import org.apache.tuscany.sdo.util.DataObjectUtil;
 import org.eclipse.emf.ecore.EClass;
@@ -233,7 +234,7 @@
   public boolean isSetReadOnly() {
     return isReadOnly();
   }
-
+  
   public org.apache.tuscany.sdo.model.Type getType_() {
     return (org.apache.tuscany.sdo.model.Type)getType();
   }
@@ -277,7 +278,47 @@
   public boolean isSetNullable() {
     return isUnsettable();
   }
+  
+  public void unsetName()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
+
+  public boolean isSetName()
+  {
+    return true;
+  }
+  
+  public void unsetOpposite()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
+
+  public boolean isSetOpposite()
+  {
+    return getOpposite() != null;
+  }
+  
+  public void unsetType()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
 
+  public boolean isSetType()
+  {
+    return true;
+  }
+  
+  public void unsetDefault()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
+
+  public boolean isSetDefault()
+  {
+    return getDefault() != null;
+  }
+  
 
   /////////////////////////////////////////////////////////////////////////////////////////////////////////
   // DataObject method implementations

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ClassImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ClassImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ClassImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ClassImpl.java Wed Feb 28 16:33:41 2007
@@ -421,6 +421,26 @@
     return isSequenced();
   }
 
+  public void unsetName()
+  {
+    throw new UnsupportedOperationException("Type is frozen and cannot be modified");
+  }
+
+  public boolean isSetName()
+  {
+    return true;
+  }
+  
+  public void unsetUri()
+  {
+    throw new UnsupportedOperationException("Type is frozen and cannot be modified");
+  }
+
+  public boolean isSetUri()
+  {
+    return true;
+  }
+
   public void setUri(String value) {
     throw new UnsupportedOperationException("Type is frozen and cannot be modified");
   }

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/DataTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/DataTypeImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/DataTypeImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/DataTypeImpl.java Wed Feb 28 16:33:41 2007
@@ -255,6 +255,26 @@
     return false;
   }
 
+  public void unsetName()
+  {
+    throw new UnsupportedOperationException("Type is frozen and cannot be modified");
+  }
+
+  public boolean isSetName()
+  {
+    return true;
+  }
+  
+  public void unsetUri()
+  {
+    throw new UnsupportedOperationException("Type is frozen and cannot be modified");
+  }
+
+  public boolean isSetUri()
+  {
+    return true;
+  }
+
   public void setUri(String value) {
     throw new UnsupportedOperationException("Type is frozen and cannot be modified");
   }

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ReferenceImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ReferenceImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ReferenceImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/impl/ReferenceImpl.java Wed Feb 28 16:33:41 2007
@@ -244,6 +244,46 @@
     return isNullable();
   }
 
+  public void unsetName()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
+
+  public boolean isSetName()
+  {
+    return true;
+  }
+  
+  public void unsetOpposite()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
+
+  public boolean isSetOpposite()
+  {
+    return getOpposite() != null;
+  }
+  
+  public void unsetType()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
+
+  public boolean isSetType()
+  {
+    return true;
+  }
+  
+  public void unsetDefault()
+  {
+    throw new UnsupportedOperationException("Property is frozen and cannot be modified");
+  }
+
+  public boolean isSetDefault()
+  {
+    return getDefault() != null;
+  }
+  
   
   /////////////////////////////////////////////////////////////////////////////////////////////////////////
   // DataObject method implementations

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/BaseDataGraphType.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/BaseDataGraphType.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/BaseDataGraphType.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/BaseDataGraphType.java Wed Feb 28 16:33:41 2007
@@ -40,6 +40,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Models</em>' containment reference.
+   * @see #isSetModels()
+   * @see #unsetModels()
    * @see #setModels(ModelsType)
    * @generated
    */
@@ -50,12 +52,37 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Models</em>' containment reference.
+   * @see #isSetModels()
+   * @see #unsetModels()
    * @see #getModels()
    * @generated
    */
   void setModels(ModelsType value);
 
   /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.BaseDataGraphType#getModels <em>Models</em>}' containment reference.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetModels()
+   * @see #getModels()
+   * @see #setModels(ModelsType)
+   * @generated
+   */
+  void unsetModels();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.BaseDataGraphType#getModels <em>Models</em>}' containment reference is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Models</em>' containment reference is set.
+   * @see #unsetModels()
+   * @see #getModels()
+   * @see #setModels(ModelsType)
+   * @generated
+   */
+  boolean isSetModels();
+
+  /**
    * Returns the value of the '<em><b>Xsd</b></em>' containment reference.
    * <!-- begin-user-doc -->
    * <p>
@@ -64,6 +91,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Xsd</em>' containment reference.
+   * @see #isSetXsd()
+   * @see #unsetXsd()
    * @see #setXsd(XSDType)
    * @generated
    */
@@ -74,12 +103,37 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Xsd</em>' containment reference.
+   * @see #isSetXsd()
+   * @see #unsetXsd()
    * @see #getXsd()
    * @generated
    */
   void setXsd(XSDType value);
 
   /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.BaseDataGraphType#getXsd <em>Xsd</em>}' containment reference.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetXsd()
+   * @see #getXsd()
+   * @see #setXsd(XSDType)
+   * @generated
+   */
+  void unsetXsd();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.BaseDataGraphType#getXsd <em>Xsd</em>}' containment reference is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Xsd</em>' containment reference is set.
+   * @see #unsetXsd()
+   * @see #getXsd()
+   * @see #setXsd(XSDType)
+   * @generated
+   */
+  boolean isSetXsd();
+
+  /**
    * Returns the value of the '<em><b>Change Summary</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <p>
@@ -88,6 +142,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Change Summary</em>' attribute.
+   * @see #isSetChangeSummary()
+   * @see #unsetChangeSummary()
    * @see #setChangeSummary(ChangeSummary)
    * @generated
    */
@@ -98,10 +154,35 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Change Summary</em>' attribute.
+   * @see #isSetChangeSummary()
+   * @see #unsetChangeSummary()
    * @see #getChangeSummary()
    * @generated
    */
   void setChangeSummary(ChangeSummary value);
+
+  /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.BaseDataGraphType#getChangeSummary <em>Change Summary</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetChangeSummary()
+   * @see #getChangeSummary()
+   * @see #setChangeSummary(ChangeSummary)
+   * @generated
+   */
+  void unsetChangeSummary();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.BaseDataGraphType#getChangeSummary <em>Change Summary</em>}' attribute is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Change Summary</em>' attribute is set.
+   * @see #unsetChangeSummary()
+   * @see #getChangeSummary()
+   * @see #setChangeSummary(ChangeSummary)
+   * @generated
+   */
+  boolean isSetChangeSummary();
 
   /**
    * Returns the value of the '<em><b>Any Attribute</b></em>' attribute list.

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/ModelFactory.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/ModelFactory.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/ModelFactory.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/ModelFactory.java Wed Feb 28 16:33:41 2007
@@ -6,6 +6,8 @@
  */
 package org.apache.tuscany.sdo.model;
 
+import commonj.sdo.helper.HelperContext;
+
 
 /**
  * <!-- begin-user-doc -->
@@ -79,4 +81,13 @@
    */
   XSDType createXSDType();
 
+  /**
+   * Registers the types supported by this Factory within the supplied scope.argument
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @param scope an instance of HelperContext used to manage the scoping of types.
+   * @generated
+   */
+  public void register(HelperContext scope);
+   
 } //ModelFactory

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Property.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Property.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Property.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Property.java Wed Feb 28 16:33:41 2007
@@ -75,6 +75,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Name</em>' attribute.
+   * @see #isSetName()
+   * @see #unsetName()
    * @see #setName(String)
    * @generated
    */
@@ -85,12 +87,37 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Name</em>' attribute.
+   * @see #isSetName()
+   * @see #unsetName()
    * @see #getName()
    * @generated
    */
   void setName(String value);
 
   /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.Property#getName <em>Name</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetName()
+   * @see #getName()
+   * @see #setName(String)
+   * @generated
+   */
+  void unsetName();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.Property#getName <em>Name</em>}' attribute is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Name</em>' attribute is set.
+   * @see #unsetName()
+   * @see #getName()
+   * @see #setName(String)
+   * @generated
+   */
+  boolean isSetName();
+
+  /**
    * Returns the value of the '<em><b>Many</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <p>
@@ -201,6 +228,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Default</em>' attribute.
+   * @see #isSetDefault()
+   * @see #unsetDefault()
    * @see #setDefault_(String)
    * @generated
    */
@@ -211,12 +240,37 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Default</em>' attribute.
+   * @see #isSetDefault()
+   * @see #unsetDefault()
    * @see #getDefault_()
    * @generated
    */
   void setDefault_(String value);
 
   /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.Property#getDefault <em>Default</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetDefault()
+   * @see #getDefault_()
+   * @see #setDefault_(String)
+   * @generated
+   */
+  void unsetDefault();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.Property#getDefault <em>Default</em>}' attribute is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Default</em>' attribute is set.
+   * @see #unsetDefault()
+   * @see #getDefault_()
+   * @see #setDefault_(String)
+   * @generated
+   */
+  boolean isSetDefault();
+
+  /**
    * Returns the value of the '<em><b>Read Only</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <p>
@@ -276,6 +330,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Type</em>' reference.
+   * @see #isSetType()
+   * @see #unsetType()
    * @see #setType(Type)
    * @generated
    */
@@ -286,12 +342,37 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Type</em>' reference.
+   * @see #isSetType()
+   * @see #unsetType()
    * @see #getType_()
    * @generated
    */
   void setType(Type value);
 
   /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.Property#getType_ <em>Type</em>}' reference.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetType()
+   * @see #getType_()
+   * @see #setType(Type)
+   * @generated
+   */
+  void unsetType();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.Property#getType_ <em>Type</em>}' reference is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Type</em>' reference is set.
+   * @see #unsetType()
+   * @see #getType_()
+   * @see #setType(Type)
+   * @generated
+   */
+  boolean isSetType();
+
+  /**
    * Returns the value of the '<em><b>Opposite</b></em>' reference.
    * <!-- begin-user-doc -->
    * <p>
@@ -300,6 +381,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Opposite</em>' reference.
+   * @see #isSetOpposite()
+   * @see #unsetOpposite()
    * @see #setOpposite_(Property)
    * @generated
    */
@@ -310,10 +393,35 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Opposite</em>' reference.
+   * @see #isSetOpposite()
+   * @see #unsetOpposite()
    * @see #getOpposite_()
    * @generated
    */
   void setOpposite_(Property value);
+
+  /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.Property#getOpposite <em>Opposite</em>}' reference.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetOpposite()
+   * @see #getOpposite_()
+   * @see #setOpposite_(Property)
+   * @generated
+   */
+  void unsetOpposite();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.Property#getOpposite <em>Opposite</em>}' reference is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Opposite</em>' reference is set.
+   * @see #unsetOpposite()
+   * @see #getOpposite_()
+   * @see #setOpposite_(Property)
+   * @generated
+   */
+  boolean isSetOpposite();
 
   /**
    * Returns the value of the '<em><b>Nullable</b></em>' attribute.

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Type.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Type.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Type.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/Type.java Wed Feb 28 16:33:41 2007
@@ -103,6 +103,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Name</em>' attribute.
+   * @see #isSetName()
+   * @see #unsetName()
    * @see #setName(String)
    * @generated
    */
@@ -113,12 +115,37 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Name</em>' attribute.
+   * @see #isSetName()
+   * @see #unsetName()
    * @see #getName()
    * @generated
    */
   void setName(String value);
 
   /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.Type#getName <em>Name</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetName()
+   * @see #getName()
+   * @see #setName(String)
+   * @generated
+   */
+  void unsetName();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.Type#getName <em>Name</em>}' attribute is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Name</em>' attribute is set.
+   * @see #unsetName()
+   * @see #getName()
+   * @see #setName(String)
+   * @generated
+   */
+  boolean isSetName();
+
+  /**
    * Returns the value of the '<em><b>Uri</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <p>
@@ -127,6 +154,8 @@
    * </p>
    * <!-- end-user-doc -->
    * @return the value of the '<em>Uri</em>' attribute.
+   * @see #isSetUri()
+   * @see #unsetUri()
    * @see #setUri(String)
    * @generated
    */
@@ -137,10 +166,35 @@
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @param value the new value of the '<em>Uri</em>' attribute.
+   * @see #isSetUri()
+   * @see #unsetUri()
    * @see #getUri()
    * @generated
    */
   void setUri(String value);
+
+  /**
+   * Unsets the value of the '{@link org.apache.tuscany.sdo.model.Type#getUri <em>Uri</em>}' attribute.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @see #isSetUri()
+   * @see #getUri()
+   * @see #setUri(String)
+   * @generated
+   */
+  void unsetUri();
+
+  /**
+   * Returns whether the value of the '{@link org.apache.tuscany.sdo.model.Type#getUri <em>Uri</em>}' attribute is set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @return whether the value of the '<em>Uri</em>' attribute is set.
+   * @see #unsetUri()
+   * @see #getUri()
+   * @see #setUri(String)
+   * @generated
+   */
+  boolean isSetUri();
 
   /**
    * Returns the value of the '<em><b>Data Type</b></em>' attribute.

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/BaseDataGraphTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/BaseDataGraphTypeImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/BaseDataGraphTypeImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/BaseDataGraphTypeImpl.java Wed Feb 28 16:33:41 2007
@@ -35,51 +35,77 @@
  */
 public abstract class BaseDataGraphTypeImpl extends DataObjectBase implements BaseDataGraphType
 {
+
+  public final static int MODELS = 0;
+
+  public final static int XSD = 1;
+
+  public final static int CHANGE_SUMMARY = 2;
+
+  public final static int ANY_ATTRIBUTE = -1;
+
+  public final static int SDO_PROPERTY_COUNT = 3;
+
+  public final static int EXTENDED_PROPERTY_COUNT = -1;
+
+
   /**
-   * The feature id for the '<em><b>Models</b></em>' containment reference.
+   * The internal feature id for the '<em><b>Models</b></em>' containment reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int MODELS = 0;
+   */ 
+  public final static int INTERNAL_MODELS = 0;
 
   /**
-   * The feature id for the '<em><b>Xsd</b></em>' containment reference.
+   * The internal feature id for the '<em><b>Xsd</b></em>' containment reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int XSD = 1;
+   */ 
+  public final static int INTERNAL_XSD = 1;
 
   /**
-   * The feature id for the '<em><b>Change Summary</b></em>' attribute.
+   * The internal feature id for the '<em><b>Change Summary</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int CHANGE_SUMMARY = 2;
+   */ 
+  public final static int INTERNAL_CHANGE_SUMMARY = 2;
 
   /**
-   * The feature id for the '<em><b>Any Attribute</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Any Attribute</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int ANY_ATTRIBUTE = 3;
+   */ 
+  public final static int INTERNAL_ANY_ATTRIBUTE = 3;
 
   /**
-   * This represents the number of properties for this type.
+   * The number of properties for this type.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
    */
-  
-  public final static int SDO_PROPERTY_COUNT = 4;
+  public final static int INTERNAL_PROPERTY_COUNT = 4;
+
+  protected int internalConvertIndex(int internalIndex)
+  {
+    switch (internalIndex)
+    {
+      case INTERNAL_MODELS: return MODELS;
+      case INTERNAL_XSD: return XSD;
+      case INTERNAL_CHANGE_SUMMARY: return CHANGE_SUMMARY;
+      case INTERNAL_ANY_ATTRIBUTE: return ANY_ATTRIBUTE;
+    }
+    return super.internalConvertIndex(internalIndex);
+  }
+
 
   /**
    * The cached value of the '{@link #getModels() <em>Models</em>}' containment reference.
@@ -93,6 +119,15 @@
   protected ModelsType models = null;
   
   /**
+   * This is true if the Models containment reference has been set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   * @ordered
+   */
+  protected boolean models_set_ = false;
+
+  /**
    * The cached value of the '{@link #getXsd() <em>Xsd</em>}' containment reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -104,6 +139,15 @@
   protected XSDType xsd = null;
   
   /**
+   * This is true if the Xsd containment reference has been set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   * @ordered
+   */
+  protected boolean xsd_set_ = false;
+
+  /**
    * The default value of the '{@link #getChangeSummary() <em>Change Summary</em>}' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -124,6 +168,15 @@
   protected ChangeSummary changeSummary = CHANGE_SUMMARY_DEFAULT_;
 
   /**
+   * This is true if the Change Summary attribute has been set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   * @ordered
+   */
+  protected boolean changeSummary_set_ = false;
+
+  /**
    * The cached value of the '{@link #getAnyAttribute() <em>Any Attribute</em>}' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -173,9 +226,11 @@
   {
     ModelsType oldModels = models;
     models = newModels;
+    boolean oldModels_set_ = models_set_;
+    models_set_ = true;
     if (isNotifying())
     {
-      addNotification(this, ChangeKind.SET, MODELS, oldModels, newModels, changeContext);
+      addNotification(this, ChangeKind.SET, MODELS, oldModels, newModels, !oldModels_set_, changeContext);
     }
     return changeContext;
   }
@@ -197,8 +252,64 @@
       changeContext = basicSetModels(newModels, changeContext);
       if (changeContext != null) dispatch(changeContext);
     }
-    else if (isNotifying())
-      notify(ChangeKind.SET, MODELS, newModels, newModels);
+    else
+    	{
+      boolean oldModels_set_ = models_set_;
+      models_set_ = true;
+      if (isNotifying())
+        notify(ChangeKind.SET, MODELS, newModels, newModels, !oldModels_set_);
+    	}
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public ChangeContext basicUnsetModels(ChangeContext changeContext)
+  {
+    ModelsType oldModels = models;
+    models = null;
+    boolean oldModels_set_ = models_set_;
+    models_set_ = false;
+    if (isNotifying())
+    {
+      addNotification(this, ChangeKind.UNSET, MODELS, oldModels, null, !oldModels_set_, changeContext);
+    }
+    return changeContext;
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void unsetModels()
+  {
+    if (models != null)
+    {
+      ChangeContext changeContext = null;
+      changeContext = inverseRemove(models, this, EOPPOSITE_FEATURE_BASE - MODELS, null, changeContext);
+      changeContext = basicUnsetModels(changeContext);
+      if (changeContext != null) dispatch(changeContext);
+    }
+    else
+    	{
+      boolean oldModels_set_ = models_set_;
+      models_set_ = false;
+      if (isNotifying())
+        notify(ChangeKind.UNSET, MODELS, null, null, oldModels_set_);
+    	}
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean isSetModels()
+  {
+    return models_set_;
   }
 
   /**
@@ -219,9 +330,11 @@
   {
     XSDType oldXsd = xsd;
     xsd = newXsd;
+    boolean oldXsd_set_ = xsd_set_;
+    xsd_set_ = true;
     if (isNotifying())
     {
-      addNotification(this, ChangeKind.SET, XSD, oldXsd, newXsd, changeContext);
+      addNotification(this, ChangeKind.SET, XSD, oldXsd, newXsd, !oldXsd_set_, changeContext);
     }
     return changeContext;
   }
@@ -243,8 +356,64 @@
       changeContext = basicSetXsd(newXsd, changeContext);
       if (changeContext != null) dispatch(changeContext);
     }
-    else if (isNotifying())
-      notify(ChangeKind.SET, XSD, newXsd, newXsd);
+    else
+    	{
+      boolean oldXsd_set_ = xsd_set_;
+      xsd_set_ = true;
+      if (isNotifying())
+        notify(ChangeKind.SET, XSD, newXsd, newXsd, !oldXsd_set_);
+    	}
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public ChangeContext basicUnsetXsd(ChangeContext changeContext)
+  {
+    XSDType oldXsd = xsd;
+    xsd = null;
+    boolean oldXsd_set_ = xsd_set_;
+    xsd_set_ = false;
+    if (isNotifying())
+    {
+      addNotification(this, ChangeKind.UNSET, XSD, oldXsd, null, !oldXsd_set_, changeContext);
+    }
+    return changeContext;
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void unsetXsd()
+  {
+    if (xsd != null)
+    {
+      ChangeContext changeContext = null;
+      changeContext = inverseRemove(xsd, this, EOPPOSITE_FEATURE_BASE - XSD, null, changeContext);
+      changeContext = basicUnsetXsd(changeContext);
+      if (changeContext != null) dispatch(changeContext);
+    }
+    else
+    	{
+      boolean oldXsd_set_ = xsd_set_;
+      xsd_set_ = false;
+      if (isNotifying())
+        notify(ChangeKind.UNSET, XSD, null, null, oldXsd_set_);
+    	}
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean isSetXsd()
+  {
+    return xsd_set_;
   }
 
   /**
@@ -265,8 +434,35 @@
   {
     ChangeSummary oldChangeSummary = changeSummary;
     changeSummary = newChangeSummary;
+    boolean oldChangeSummary_set_ = changeSummary_set_;
+    changeSummary_set_ = true;
     if (isNotifying())
-      notify(ChangeKind.SET, CHANGE_SUMMARY, oldChangeSummary, changeSummary);
+      notify(ChangeKind.SET, CHANGE_SUMMARY, oldChangeSummary, changeSummary, !oldChangeSummary_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void unsetChangeSummary()
+  {
+    ChangeSummary oldChangeSummary = changeSummary;
+    boolean oldChangeSummary_set_ = changeSummary_set_;
+    changeSummary = CHANGE_SUMMARY_DEFAULT_;
+    changeSummary_set_ = false;
+    if (isNotifying())
+      notify(ChangeKind.UNSET, CHANGE_SUMMARY, oldChangeSummary, CHANGE_SUMMARY_DEFAULT_, oldChangeSummary_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean isSetChangeSummary()
+  {
+    return changeSummary_set_;
   }
 
   /**
@@ -278,7 +474,7 @@
   {
     if (anyAttribute == null)
     {
-      anyAttribute = createSequence(ANY_ATTRIBUTE);
+      anyAttribute = createSequence(INTERNAL_ANY_ATTRIBUTE);
     }
     return anyAttribute;
   }
@@ -292,9 +488,9 @@
     switch (propertyIndex)
     {
       case MODELS:
-        return basicSetModels(null, changeContext);
+        return basicUnsetModels(changeContext);
       case XSD:
-        return basicSetXsd(null, changeContext);
+        return basicUnsetXsd(changeContext);
       case ANY_ATTRIBUTE:
         return removeFromSequence(getAnyAttribute(), otherEnd, changeContext);
     }
@@ -359,13 +555,13 @@
     switch (propertyIndex)
     {
       case MODELS:
-        setModels((ModelsType)null);
+        unsetModels();
         return;
       case XSD:
-        setXsd((XSDType)null);
+        unsetXsd();
         return;
       case CHANGE_SUMMARY:
-        setChangeSummary(CHANGE_SUMMARY_DEFAULT_);
+        unsetChangeSummary();
         return;
       case ANY_ATTRIBUTE:
         unsetSequence(getAnyAttribute());
@@ -384,11 +580,11 @@
     switch (propertyIndex)
     {
       case MODELS:
-        return models != null;
+        return isSetModels();
       case XSD:
-        return xsd != null;
+        return isSetXsd();
       case CHANGE_SUMMARY:
-        return CHANGE_SUMMARY_DEFAULT_ == null ? changeSummary != null : !CHANGE_SUMMARY_DEFAULT_.equals(changeSummary);
+        return isSetChangeSummary();
       case ANY_ATTRIBUTE:
         return anyAttribute != null && !isSequenceEmpty(getAnyAttribute());
     }
@@ -406,7 +602,7 @@
 
     StringBuffer result = new StringBuffer(super.toString());
     result.append(" (changeSummary: ");
-    result.append(changeSummary);
+    if (changeSummary_set_) result.append(changeSummary); else result.append("<unset>");
     result.append(", anyAttribute: ");
     result.append(anyAttribute);
     result.append(')');

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataGraphTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataGraphTypeImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataObjectImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataObjectImpl.java Wed Feb 28 16:33:41 2007
@@ -24,15 +24,29 @@
  */
 public abstract class DataObjectImpl extends DataObjectBase implements DataObject
 {
+
+  public final static int SDO_PROPERTY_COUNT = 0;
+
+  public final static int EXTENDED_PROPERTY_COUNT = 0;
+
+
   /**
-   * This represents the number of properties for this type.
+   * The number of properties for this type.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
    */
-  
-  public final static int SDO_PROPERTY_COUNT = 0;
+  public final static int INTERNAL_PROPERTY_COUNT = 0;
+
+  protected int internalConvertIndex(int internalIndex)
+  {
+    switch (internalIndex)
+    {
+    }
+    return super.internalConvertIndex(internalIndex);
+  }
+
 
   /**
    * <!-- begin-user-doc -->

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelFactoryImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelFactoryImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelFactoryImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelFactoryImpl.java Wed Feb 28 16:33:41 2007
@@ -6,9 +6,12 @@
  */
 package org.apache.tuscany.sdo.model.impl;
 
+import commonj.sdo.helper.DataHelper;
+import commonj.sdo.helper.HelperContext;
+import org.apache.tuscany.sdo.helper.TypeHelperImpl;
+
 import commonj.sdo.ChangeSummary;
 import commonj.sdo.DataObject;
-import commonj.sdo.helper.DataHelper;
 
 import java.math.BigDecimal;
 import java.math.BigInteger;
@@ -40,18 +43,16 @@
  *         setDefault() to setDefault_();
  *         getOpposite() to getOpposite_();
  *         setOpposite() to setOpposite_();
- *   3. Change the value of the NAMESPACE_PREFIX to "sdo"
- *           public static final String NAMESPACE_PREFIX = "sdo"; //FB generated as "commonj"
- *   4. Copy the following method from the old to new generated Type/TypeImpl interface and implemention class (resolve any missing imports):
+ *   3. Copy the following method from the old to new generated Type/TypeImpl interface and implemention class (resolve any missing imports):
  *         String getInstanceClassName();
- *   5. Copy the following method from the old to new generated Types/TypesImpl interface and implemention class (resolve any missing imports):
+ *   4. Copy the following method from the old to new generated Types/TypesImpl interface and implemention class (resolve any missing imports):
  *         List getTypeList();
- *   6. Delete all the createXXXFromString() and convertXXXToString() methods in the newly generated ModelFactoryImpl and
+ *   5. Delete all the createXXXFromString() and convertXXXToString() methods in the newly generated ModelFactoryImpl and
  *      replace them with the ones from this file (resolve any missing imports).
- *   7. Comment out the call to registerStaticTypes of ModelFactory.class in the init() method
- *   8. Change org.apache.tuscany.sdo.model.DataObject.class to commonj.sdo.DataObject.class for the following method found in method initializeMetaData();
+ *   6. Comment out the call to registerStaticTypes of ModelFactory.class in the init() method
+ *   7. Change org.apache.tuscany.sdo.model.DataObject.class to commonj.sdo.DataObject.class for the following method found in method initializeMetaData();
  *         initializeType(dataObjectType, commonj.sdo.DataObject.class, "DataObject", true); // generated as org.apache.tuscany.sdo.model.DataObject.class
- *   9. Move this JavaDoc comment into the newly generated ModelFactoryImpl class.
+ *   8. Move this JavaDoc comment into the newly generated ModelFactoryImpl class.
  * <!-- end-user-doc -->
  * @generated
  */
@@ -72,7 +73,16 @@
    * <!-- end-user-doc -->
    * @generated
    */
-  public static final String NAMESPACE_PREFIX = "sdo"; //FB generated as "commonj"     
+  public static final String NAMESPACE_PREFIX = "sdo";
+
+  /**
+   * The version of the generator pattern used to generate this class.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public static final String PATTERN_VERSION = "1.1";
+  
   public static final int BASE_DATA_GRAPH_TYPE = 1;	
   public static final int DATA_GRAPH_TYPE = 2;	
   public static final int DATA_OBJECT = 3;	
@@ -128,6 +138,21 @@
   {
     super(NAMESPACE_URI, NAMESPACE_PREFIX, "org.apache.tuscany.sdo.model");
   }
+
+  /**
+   * Registers the Factory instance so that it is available within the supplied scope.
+   * @argument scope a HelperContext instance that will make the types supported by this Factory available.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */	
+  public void register(HelperContext scope) {
+    if(scope == null) {
+       throw new IllegalArgumentException("Scope can not be null");
+    } 
+    TypeHelperImpl th = (TypeHelperImpl)scope.getTypeHelper();
+    th.getExtendedMetaData().putPackage(NAMESPACE_URI, this);
+  }
   
   /**
    * <!-- begin-user-doc -->
@@ -697,7 +722,7 @@
 
     // Initialize simple dependencies
     SDOUtil.registerStaticTypes(SDOFactory.class);
-    // SDOUtil.registerStaticTypes(ModelFactory.class);
+    //SDOUtil.registerStaticTypes(ModelFactory.class);
 
     // Create package meta-data objects
     theModelFactoryImpl.createMetaData();
@@ -719,54 +744,46 @@
     isCreated = true;	
 
     // Create types and their properties
-    baseDataGraphTypeType = createType(false, BASE_DATA_GRAPH_TYPE);
-    createProperty(false, baseDataGraphTypeType, BaseDataGraphTypeImpl.MODELS);
-    createProperty(false, baseDataGraphTypeType, BaseDataGraphTypeImpl.XSD);
-    createProperty(true, baseDataGraphTypeType, BaseDataGraphTypeImpl.CHANGE_SUMMARY);
-    createProperty(true, baseDataGraphTypeType, BaseDataGraphTypeImpl.ANY_ATTRIBUTE);
-
-    dataGraphTypeType = createType(false, DATA_GRAPH_TYPE);
-    createProperty(true, dataGraphTypeType, DataGraphTypeImpl.ANY);
-
-    dataObjectType = createType(false, DATA_OBJECT);
-
-    modelsTypeType = createType(false, MODELS_TYPE);
-    createProperty(true, modelsTypeType, ModelsTypeImpl.ANY);
-
-    propertyType = createType(false, PROPERTY);
-    createProperty(true, propertyType, PropertyImpl.ALIAS_NAME);
-    createProperty(true, propertyType, PropertyImpl.ANY);
-    createProperty(true, propertyType, PropertyImpl.NAME);
-    createProperty(true, propertyType, PropertyImpl.MANY);
-    createProperty(true, propertyType, PropertyImpl.CONTAINMENT);
-    createProperty(true, propertyType, PropertyImpl.DEFAULT);
-    createProperty(true, propertyType, PropertyImpl.READ_ONLY);
-    createProperty(false, propertyType, PropertyImpl.TYPE);
-    createProperty(false, propertyType, PropertyImpl.OPPOSITE);
-    createProperty(true, propertyType, PropertyImpl.NULLABLE);
-    createProperty(true, propertyType, PropertyImpl.ANY_ATTRIBUTE);
-
-    textTypeType = createType(false, TEXT_TYPE);
-    createProperty(true, textTypeType, TextTypeImpl.TEXT);
-
-    typeType = createType(false, TYPE);
-    createProperty(false, typeType, TypeImpl.BASE_TYPE);
-    createProperty(false, typeType, TypeImpl.PROPERTY);
-    createProperty(true, typeType, TypeImpl.ALIAS_NAME);
-    createProperty(true, typeType, TypeImpl.ANY);
-    createProperty(true, typeType, TypeImpl.NAME);
-    createProperty(true, typeType, TypeImpl.URI);
-    createProperty(true, typeType, TypeImpl.DATA_TYPE);
-    createProperty(true, typeType, TypeImpl.OPEN);
-    createProperty(true, typeType, TypeImpl.SEQUENCED);
-    createProperty(true, typeType, TypeImpl.ABSTRACT);
-    createProperty(true, typeType, TypeImpl.ANY_ATTRIBUTE);
-
-    typesType = createType(false, TYPES);
-    createProperty(false, typesType, TypesImpl.TYPE);
-
-    xsdTypeType = createType(false, XSD_TYPE);
-    createProperty(true, xsdTypeType, XSDTypeImpl.ANY);
+          baseDataGraphTypeType = createType(false, BASE_DATA_GRAPH_TYPE);
+    createProperty(false, baseDataGraphTypeType,BaseDataGraphTypeImpl.INTERNAL_MODELS); 
+    createProperty(false, baseDataGraphTypeType,BaseDataGraphTypeImpl.INTERNAL_XSD); 
+    createProperty(true, baseDataGraphTypeType,BaseDataGraphTypeImpl.INTERNAL_CHANGE_SUMMARY); 
+    createProperty(true, baseDataGraphTypeType,BaseDataGraphTypeImpl.INTERNAL_ANY_ATTRIBUTE); 
+          dataGraphTypeType = createType(false, DATA_GRAPH_TYPE);
+    createProperty(true, dataGraphTypeType,DataGraphTypeImpl.INTERNAL_ANY); 
+          dataObjectType = createType(false, DATA_OBJECT);
+          modelsTypeType = createType(false, MODELS_TYPE);
+    createProperty(true, modelsTypeType,ModelsTypeImpl.INTERNAL_ANY); 
+          propertyType = createType(false, PROPERTY);
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_ALIAS_NAME); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_ANY); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_NAME); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_MANY); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_CONTAINMENT); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_DEFAULT); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_READ_ONLY); 
+    createProperty(false, propertyType,PropertyImpl.INTERNAL_TYPE); 
+    createProperty(false, propertyType,PropertyImpl.INTERNAL_OPPOSITE); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_NULLABLE); 
+    createProperty(true, propertyType,PropertyImpl.INTERNAL_ANY_ATTRIBUTE); 
+          textTypeType = createType(false, TEXT_TYPE);
+    createProperty(true, textTypeType,TextTypeImpl.INTERNAL_TEXT); 
+          typeType = createType(false, TYPE);
+    createProperty(false, typeType,TypeImpl.INTERNAL_BASE_TYPE); 
+    createProperty(false, typeType,TypeImpl.INTERNAL_PROPERTY); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_ALIAS_NAME); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_ANY); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_NAME); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_URI); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_DATA_TYPE); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_OPEN); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_SEQUENCED); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_ABSTRACT); 
+    createProperty(true, typeType,TypeImpl.INTERNAL_ANY_ATTRIBUTE); 
+          typesType = createType(false, TYPES);
+    createProperty(false, typesType,TypesImpl.INTERNAL_TYPE); 
+          xsdTypeType = createType(false, XSD_TYPE);
+    createProperty(true, xsdTypeType,XSDTypeImpl.INTERNAL_ANY); 
 
     // Create data types
     base64BytesType = createType(true, BASE64_BYTES );
@@ -819,87 +836,109 @@
 
     // Initialize types and properties
     initializeType(baseDataGraphTypeType, BaseDataGraphType.class, "BaseDataGraphType", true);
-    property = (commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.MODELS);
-    initializeProperty(property, this.getModelsType(), "models", null, 0, 1, BaseDataGraphType.class, false, false, false, true, null);
-    property = (commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.XSD);
-    initializeProperty(property, this.getXSDType(), "xsd", null, 0, 1, BaseDataGraphType.class, false, false, false, true, null);
-    property = (commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.CHANGE_SUMMARY);
-    initializeProperty(property, this.getChangeSummaryType(), "changeSummary", null, 0, 1, BaseDataGraphType.class, false, false, false);
-    property = (commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.ANY_ATTRIBUTE);
+    property = getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_MODELS);
+    initializeProperty(property, this.getModelsType(), "models", null, 0, 1, BaseDataGraphType.class, false, true, false, true , null);
+
+    property = getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_XSD);
+    initializeProperty(property, this.getXSDType(), "xsd", null, 0, 1, BaseDataGraphType.class, false, true, false, true , null);
+
+    property = getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_CHANGE_SUMMARY);
+    initializeProperty(property, this.getChangeSummaryType(), "changeSummary", null, 0, 1, BaseDataGraphType.class, false, true, false);
+
+    property = getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_ANY_ATTRIBUTE);
     initializeProperty(property, getSequence(), "anyAttribute", null, 0, -1, BaseDataGraphType.class, false, false, false);
 
     initializeType(dataGraphTypeType, DataGraphType.class, "DataGraphType", false);
-    property = (commonj.sdo.Property)dataGraphTypeType.getProperties().get(DataGraphTypeImpl.ANY);
+    property = getProperty(dataGraphTypeType, DataGraphTypeImpl.INTERNAL_ANY);
     initializeProperty(property, getSequence(), "any", null, 0, 1, DataGraphType.class, false, false, false);
 
     initializeType(dataObjectType, commonj.sdo.DataObject.class, "DataObject", true);
-
     initializeType(modelsTypeType, ModelsType.class, "ModelsType", false);
-    property = (commonj.sdo.Property)modelsTypeType.getProperties().get(ModelsTypeImpl.ANY);
+    property = getProperty(modelsTypeType, ModelsTypeImpl.INTERNAL_ANY);
     initializeProperty(property, getSequence(), "any", null, 0, -1, ModelsType.class, false, false, false);
 
     initializeType(propertyType, Property.class, "Property", false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.ALIAS_NAME);
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_ALIAS_NAME);
     initializeProperty(property, this.getString(), "aliasName", null, 0, -1, Property.class, false, false, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.ANY);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_ANY);
     initializeProperty(property, getSequence(), "any", null, 0, -1, Property.class, false, false, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.NAME);
-    initializeProperty(property, this.getString(), "name", null, 0, 1, Property.class, false, false, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.MANY);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_NAME);
+    initializeProperty(property, this.getString(), "name", null, 0, 1, Property.class, false, true, false);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_MANY);
     initializeProperty(property, this.getBoolean(), "many", null, 0, 1, Property.class, false, true, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.CONTAINMENT);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_CONTAINMENT);
     initializeProperty(property, this.getBoolean(), "containment", null, 0, 1, Property.class, false, true, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.DEFAULT);
-    initializeProperty(property, this.getString(), "default", null, 0, 1, Property.class, false, false, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.READ_ONLY);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_DEFAULT);
+    initializeProperty(property, this.getString(), "default_", null, 0, 1, Property.class, false, true, false);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_READ_ONLY);
     initializeProperty(property, this.getBoolean(), "readOnly", null, 0, 1, Property.class, false, true, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.TYPE);
-    initializeProperty(property, this.getType(), "type", null, 0, 1, Property.class, false, false, false, false, null);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_TYPE);
+    initializeProperty(property, this.getType(), "type", null, 0, 1, Property.class, false, true, false, false , null);
     setInstanceProperty (property, "commonj.sdo/xml", "propertyType", "sdo:Type");
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.OPPOSITE);
-    initializeProperty(property, this.getProperty(), "opposite", null, 0, 1, Property.class, false, false, false, false, null);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_OPPOSITE);
+    initializeProperty(property, this.getProperty(), "opposite", null, 0, 1, Property.class, false, true, false, false , null);
     setInstanceProperty (property, "commonj.sdo/xml", "propertyType", "sdo:Property");
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.NULLABLE);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_NULLABLE);
     initializeProperty(property, this.getBoolean(), "nullable", null, 0, 1, Property.class, false, true, false);
-    property = (commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.ANY_ATTRIBUTE);
+
+    property = getProperty(propertyType, PropertyImpl.INTERNAL_ANY_ATTRIBUTE);
     initializeProperty(property, getSequence(), "anyAttribute", null, 0, -1, Property.class, false, false, false);
 
     initializeType(textTypeType, TextType.class, "TextType", true);
-    property = (commonj.sdo.Property)textTypeType.getProperties().get(TextTypeImpl.TEXT);
+    property = getProperty(textTypeType, TextTypeImpl.INTERNAL_TEXT);
     initializeProperty(property, this.getString(), "text", null, 0, -1, TextType.class, false, false, false);
 
     initializeType(typeType, Type.class, "Type", false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.BASE_TYPE);
-    initializeProperty(property, this.getType(), "baseType", null, 0, -1, Type.class, false, false, false, false, null);
+    property = getProperty(typeType, TypeImpl.INTERNAL_BASE_TYPE);
+    initializeProperty(property, this.getType(), "baseType", null, 0, -1, Type.class, false, false, false, false , null);
     setInstanceProperty (property, "commonj.sdo/xml", "propertyType", "sdo:Type");
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.PROPERTY);
-    initializeProperty(property, this.getProperty(), "property", null, 0, -1, Type.class, false, false, false, true, null);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ALIAS_NAME);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_PROPERTY);
+    initializeProperty(property, this.getProperty(), "property", null, 0, -1, Type.class, false, false, false, true , null);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_ALIAS_NAME);
     initializeProperty(property, this.getString(), "aliasName", null, 0, -1, Type.class, false, false, false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ANY);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_ANY);
     initializeProperty(property, getSequence(), "any", null, 0, -1, Type.class, false, false, false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.NAME);
-    initializeProperty(property, this.getString(), "name", null, 0, 1, Type.class, false, false, false);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_NAME);
+    initializeProperty(property, this.getString(), "name", null, 0, 1, Type.class, false, true, false);
     setInstanceProperty (property, "commonj.sdo/xml", "dataType", "sdo:String");
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.URI);
-    initializeProperty(property, this.getURI(), "uri", null, 0, 1, Type.class, false, false, false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.DATA_TYPE);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_URI);
+    initializeProperty(property, this.getURI(), "uri", null, 0, 1, Type.class, false, true, false);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_DATA_TYPE);
     initializeProperty(property, this.getBoolean(), "dataType", null, 0, 1, Type.class, false, true, false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.OPEN);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_OPEN);
     initializeProperty(property, this.getBoolean(), "open", null, 0, 1, Type.class, false, true, false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.SEQUENCED);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_SEQUENCED);
     initializeProperty(property, this.getBoolean(), "sequenced", null, 0, 1, Type.class, false, true, false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ABSTRACT);
-    initializeProperty(property, this.getBoolean(), "abstract", null, 0, 1, Type.class, false, true, false);
-    property = (commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ANY_ATTRIBUTE);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_ABSTRACT);
+    initializeProperty(property, this.getBoolean(), "abstract_", null, 0, 1, Type.class, false, true, false);
+
+    property = getProperty(typeType, TypeImpl.INTERNAL_ANY_ATTRIBUTE);
     initializeProperty(property, getSequence(), "anyAttribute", null, 0, -1, Type.class, false, false, false);
 
     initializeType(typesType, Types.class, "Types", false);
-    property = (commonj.sdo.Property)typesType.getProperties().get(TypesImpl.TYPE);
-    initializeProperty(property, this.getType(), "type", null, 0, -1, Types.class, false, false, false, true, null);
+    property = getProperty(typesType, TypesImpl.INTERNAL_TYPE);
+    initializeProperty(property, this.getType(), "type", null, 0, -1, Types.class, false, false, false, true , null);
 
     initializeType(xsdTypeType, XSDType.class, "XSDType", false);
-    property = (commonj.sdo.Property)xsdTypeType.getProperties().get(XSDTypeImpl.ANY);
+    property = getProperty(xsdTypeType, XSDTypeImpl.INTERNAL_ANY);
     initializeProperty(property, getSequence(), "any", null, 0, -1, XSDType.class, false, false, false);
 
     // Initialize data types
@@ -1009,6 +1048,7 @@
     
     commonj.sdo.Property property = null;
     
+
     addXSDMapping
       (baseDataGraphTypeType,
        new String[] 
@@ -1018,7 +1058,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.MODELS),
+      (getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_MODELS),
        new String[]
        {
        "kind", "element",
@@ -1026,7 +1066,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.XSD),
+      (getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_XSD),
        new String[]
        {
        "kind", "element",
@@ -1034,7 +1074,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.CHANGE_SUMMARY),
+      (getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_CHANGE_SUMMARY),
        new String[]
        {
        "kind", "element",
@@ -1042,7 +1082,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)baseDataGraphTypeType.getProperties().get(BaseDataGraphTypeImpl.ANY_ATTRIBUTE),
+      (getProperty(baseDataGraphTypeType, BaseDataGraphTypeImpl.INTERNAL_ANY_ATTRIBUTE),
        new String[]
        {
        "kind", "attributeWildcard",
@@ -1060,7 +1100,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)dataGraphTypeType.getProperties().get(DataGraphTypeImpl.ANY),
+      (getProperty(dataGraphTypeType, DataGraphTypeImpl.INTERNAL_ANY),
        new String[]
        {
        "kind", "elementWildcard",
@@ -1148,7 +1188,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)modelsTypeType.getProperties().get(ModelsTypeImpl.ANY),
+      (getProperty(modelsTypeType, ModelsTypeImpl.INTERNAL_ANY),
        new String[]
        {
        "kind", "elementWildcard",
@@ -1166,7 +1206,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.ALIAS_NAME),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_ALIAS_NAME),
        new String[]
        {
        "kind", "element",
@@ -1175,7 +1215,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.ANY),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_ANY),
        new String[]
        {
        "kind", "elementWildcard",
@@ -1185,7 +1225,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.NAME),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_NAME),
        new String[]
        {
        "kind", "attribute",
@@ -1193,7 +1233,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.MANY),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_MANY),
        new String[]
        {
        "kind", "attribute",
@@ -1201,7 +1241,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.CONTAINMENT),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_CONTAINMENT),
        new String[]
        {
        "kind", "attribute",
@@ -1209,7 +1249,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.DEFAULT),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_DEFAULT),
        new String[]
        {
        "kind", "attribute",
@@ -1217,7 +1257,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.READ_ONLY),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_READ_ONLY),
        new String[]
        {
        "kind", "attribute",
@@ -1225,7 +1265,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.TYPE),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_TYPE),
        new String[]
        {
        "kind", "attribute",
@@ -1233,7 +1273,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.OPPOSITE),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_OPPOSITE),
        new String[]
        {
        "kind", "attribute",
@@ -1241,7 +1281,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.NULLABLE),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_NULLABLE),
        new String[]
        {
        "kind", "attribute",
@@ -1249,7 +1289,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)propertyType.getProperties().get(PropertyImpl.ANY_ATTRIBUTE),
+      (getProperty(propertyType, PropertyImpl.INTERNAL_ANY_ATTRIBUTE),
        new String[]
        {
        "kind", "attributeWildcard",
@@ -1267,7 +1307,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)textTypeType.getProperties().get(TextTypeImpl.TEXT),
+      (getProperty(textTypeType, TextTypeImpl.INTERNAL_TEXT),
        new String[]
        {
        "kind", "element",
@@ -1284,7 +1324,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.BASE_TYPE),
+      (getProperty(typeType, TypeImpl.INTERNAL_BASE_TYPE),
        new String[]
        {
        "kind", "element",
@@ -1293,7 +1333,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.PROPERTY),
+      (getProperty(typeType, TypeImpl.INTERNAL_PROPERTY),
        new String[]
        {
        "kind", "element",
@@ -1302,7 +1342,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ALIAS_NAME),
+      (getProperty(typeType, TypeImpl.INTERNAL_ALIAS_NAME),
        new String[]
        {
        "kind", "element",
@@ -1311,7 +1351,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ANY),
+      (getProperty(typeType, TypeImpl.INTERNAL_ANY),
        new String[]
        {
        "kind", "elementWildcard",
@@ -1321,7 +1361,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.NAME),
+      (getProperty(typeType, TypeImpl.INTERNAL_NAME),
        new String[]
        {
        "kind", "attribute",
@@ -1329,7 +1369,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.URI),
+      (getProperty(typeType, TypeImpl.INTERNAL_URI),
        new String[]
        {
        "kind", "attribute",
@@ -1337,7 +1377,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.DATA_TYPE),
+      (getProperty(typeType, TypeImpl.INTERNAL_DATA_TYPE),
        new String[]
        {
        "kind", "attribute",
@@ -1345,7 +1385,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.OPEN),
+      (getProperty(typeType, TypeImpl.INTERNAL_OPEN),
        new String[]
        {
        "kind", "attribute",
@@ -1353,7 +1393,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.SEQUENCED),
+      (getProperty(typeType, TypeImpl.INTERNAL_SEQUENCED),
        new String[]
        {
        "kind", "attribute",
@@ -1361,7 +1401,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ABSTRACT),
+      (getProperty(typeType, TypeImpl.INTERNAL_ABSTRACT),
        new String[]
        {
        "kind", "attribute",
@@ -1369,7 +1409,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typeType.getProperties().get(TypeImpl.ANY_ATTRIBUTE),
+      (getProperty(typeType, TypeImpl.INTERNAL_ANY_ATTRIBUTE),
        new String[]
        {
        "kind", "attributeWildcard",
@@ -1387,7 +1427,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)typesType.getProperties().get(TypesImpl.TYPE),
+      (getProperty(typesType, TypesImpl.INTERNAL_TYPE),
        new String[]
        {
        "kind", "element",
@@ -1404,7 +1444,7 @@
        });
 
     addXSDMapping
-      ((commonj.sdo.Property)xsdTypeType.getProperties().get(XSDTypeImpl.ANY),
+      (getProperty(xsdTypeType, XSDTypeImpl.INTERNAL_ANY),
        new String[]
        {
        "kind", "elementWildcard",
@@ -1667,7 +1707,7 @@
        });
 
   }
-  
+    
   /**
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -2389,5 +2429,5 @@
   {
       return (String)instanceValue;
   }
-
+   
 } //ModelFactoryImpl

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelsTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelsTypeImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/PropertyImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/PropertyImpl.java Wed Feb 28 16:33:41 2007
@@ -42,114 +42,161 @@
  */
 public class PropertyImpl extends DataObjectBase implements Property
 {
+
+  public final static int ALIAS_NAME = 0;
+
+  public final static int ANY = -1;
+
+  public final static int NAME = 1;
+
+  public final static int MANY = 2;
+
+  public final static int CONTAINMENT = 3;
+
+  public final static int DEFAULT = 4;
+
+  public final static int READ_ONLY = 5;
+
+  public final static int TYPE = 6;
+
+  public final static int OPPOSITE = 7;
+
+  public final static int NULLABLE = 8;
+
+  public final static int ANY_ATTRIBUTE = -2;
+
+  public final static int SDO_PROPERTY_COUNT = 9;
+
+  public final static int EXTENDED_PROPERTY_COUNT = -2;
+
+
   /**
-   * The feature id for the '<em><b>Alias Name</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Alias Name</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int ALIAS_NAME = 0;
+   */ 
+  public final static int INTERNAL_ALIAS_NAME = 0;
 
   /**
-   * The feature id for the '<em><b>Any</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Any</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int ANY = 1;
+   */ 
+  public final static int INTERNAL_ANY = 1;
 
   /**
-   * The feature id for the '<em><b>Name</b></em>' attribute.
+   * The internal feature id for the '<em><b>Name</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int NAME = 2;
+   */ 
+  public final static int INTERNAL_NAME = 2;
 
   /**
-   * The feature id for the '<em><b>Many</b></em>' attribute.
+   * The internal feature id for the '<em><b>Many</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int MANY = 3;
+   */ 
+  public final static int INTERNAL_MANY = 3;
 
   /**
-   * The feature id for the '<em><b>Containment</b></em>' attribute.
+   * The internal feature id for the '<em><b>Containment</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int CONTAINMENT = 4;
+   */ 
+  public final static int INTERNAL_CONTAINMENT = 4;
 
   /**
-   * The feature id for the '<em><b>Default</b></em>' attribute.
+   * The internal feature id for the '<em><b>Default</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int DEFAULT = 5;
+   */ 
+  public final static int INTERNAL_DEFAULT = 5;
 
   /**
-   * The feature id for the '<em><b>Read Only</b></em>' attribute.
+   * The internal feature id for the '<em><b>Read Only</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int READ_ONLY = 6;
+   */ 
+  public final static int INTERNAL_READ_ONLY = 6;
 
   /**
-   * The feature id for the '<em><b>Type</b></em>' reference.
+   * The internal feature id for the '<em><b>Type</b></em>' reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int TYPE = 7;
+   */ 
+  public final static int INTERNAL_TYPE = 7;
 
   /**
-   * The feature id for the '<em><b>Opposite</b></em>' reference.
+   * The internal feature id for the '<em><b>Opposite</b></em>' reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int OPPOSITE = 8;
+   */ 
+  public final static int INTERNAL_OPPOSITE = 8;
 
   /**
-   * The feature id for the '<em><b>Nullable</b></em>' attribute.
+   * The internal feature id for the '<em><b>Nullable</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int NULLABLE = 9;
+   */ 
+  public final static int INTERNAL_NULLABLE = 9;
 
   /**
-   * The feature id for the '<em><b>Any Attribute</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Any Attribute</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int ANY_ATTRIBUTE = 10;
+   */ 
+  public final static int INTERNAL_ANY_ATTRIBUTE = 10;
 
   /**
-   * This represents the number of properties for this type.
+   * The number of properties for this type.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
    */
-  
-  public final static int SDO_PROPERTY_COUNT = 11;
+  public final static int INTERNAL_PROPERTY_COUNT = 11;
+
+  protected int internalConvertIndex(int internalIndex)
+  {
+    switch (internalIndex)
+    {
+      case INTERNAL_ALIAS_NAME: return ALIAS_NAME;
+      case INTERNAL_ANY: return ANY;
+      case INTERNAL_NAME: return NAME;
+      case INTERNAL_MANY: return MANY;
+      case INTERNAL_CONTAINMENT: return CONTAINMENT;
+      case INTERNAL_DEFAULT: return DEFAULT;
+      case INTERNAL_READ_ONLY: return READ_ONLY;
+      case INTERNAL_TYPE: return TYPE;
+      case INTERNAL_OPPOSITE: return OPPOSITE;
+      case INTERNAL_NULLABLE: return NULLABLE;
+      case INTERNAL_ANY_ATTRIBUTE: return ANY_ATTRIBUTE;
+    }
+    return super.internalConvertIndex(internalIndex);
+  }
+
 
   /**
    * The cached value of the '{@link #getAliasName() <em>Alias Name</em>}' attribute list.
@@ -194,6 +241,15 @@
   protected String name = NAME_DEFAULT_;
 
   /**
+   * This is true if the Name attribute has been set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   * @ordered
+   */
+  protected boolean name_set_ = false;
+
+  /**
    * The default value of the '{@link #isMany() <em>Many</em>}' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -272,6 +328,15 @@
   protected String default_ = DEFAULT_DEFAULT_;
 
   /**
+   * This is true if the Default attribute has been set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   * @ordered
+   */
+  protected boolean default_set_ = false;
+
+  /**
    * The default value of the '{@link #isReadOnly() <em>Read Only</em>}' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -312,6 +377,15 @@
   protected Type type = null;
   
   /**
+   * This is true if the Type reference has been set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   * @ordered
+   */
+  protected boolean type_set_ = false;
+
+  /**
    * The cached value of the '{@link #getOpposite_() <em>Opposite</em>}' reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -323,6 +397,15 @@
   protected Property opposite = null;
   
   /**
+   * This is true if the Opposite reference has been set.
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   * @ordered
+   */
+  protected boolean opposite_set_ = false;
+
+  /**
    * The default value of the '{@link #isNullable() <em>Nullable</em>}' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -404,7 +487,7 @@
   {
     if (any == null)
     {
-      any = createSequence(ANY);
+      any = createSequence(INTERNAL_ANY);
     }
     return any;
   }
@@ -426,8 +509,35 @@
   {
     String oldName = name;
     name = newName;
+    boolean oldName_set_ = name_set_;
+    name_set_ = true;
+    if (isNotifying())
+      notify(ChangeKind.SET, NAME, oldName, name, !oldName_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void unsetName()
+  {
+    String oldName = name;
+    boolean oldName_set_ = name_set_;
+    name = NAME_DEFAULT_;
+    name_set_ = false;
     if (isNotifying())
-      notify(ChangeKind.SET, NAME, oldName, name);
+      notify(ChangeKind.UNSET, NAME, oldName, NAME_DEFAULT_, oldName_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean isSetName()
+  {
+    return name_set_;
   }
 
   /**
@@ -546,8 +656,35 @@
   {
     String oldDefault = default_;
     default_ = newDefault;
+    boolean oldDefault_set_ = default_set_;
+    default_set_ = true;
     if (isNotifying())
-      notify(ChangeKind.SET, DEFAULT, oldDefault, default_);
+      notify(ChangeKind.SET, DEFAULT, oldDefault, default_, !oldDefault_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void unsetDefault()
+  {
+    String oldDefault = default_;
+    boolean oldDefault_set_ = default_set_;
+    default_ = DEFAULT_DEFAULT_;
+    default_set_ = false;
+    if (isNotifying())
+      notify(ChangeKind.UNSET, DEFAULT, oldDefault, DEFAULT_DEFAULT_, oldDefault_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean isSetDefault()
+  {
+    return default_set_;
   }
 
   /**
@@ -637,8 +774,35 @@
   {
     Type oldType = type;
     type = newType;
+    boolean oldType_set_ = type_set_;
+    type_set_ = true;
+    if (isNotifying())
+      notify(ChangeKind.SET, TYPE, oldType, type, !oldType_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void unsetType()
+  {
+    Type oldType = type;
+    boolean oldType_set_ = type_set_;
+    type = null;
+    type_set_ = false;
     if (isNotifying())
-      notify(ChangeKind.SET, TYPE, oldType, type);
+      notify(ChangeKind.UNSET, TYPE, oldType, null, oldType_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean isSetType()
+  {
+    return type_set_;
   }
 
   /**
@@ -679,8 +843,35 @@
   {
     Property oldOpposite = opposite;
     opposite = newOpposite;
+    boolean oldOpposite_set_ = opposite_set_;
+    opposite_set_ = true;
     if (isNotifying())
-      notify(ChangeKind.SET, OPPOSITE, oldOpposite, opposite);
+      notify(ChangeKind.SET, OPPOSITE, oldOpposite, opposite, !oldOpposite_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public void unsetOpposite()
+  {
+    Property oldOpposite = opposite;
+    boolean oldOpposite_set_ = opposite_set_;
+    opposite = null;
+    opposite_set_ = false;
+    if (isNotifying())
+      notify(ChangeKind.UNSET, OPPOSITE, oldOpposite, null, oldOpposite_set_);
+  }
+
+  /**
+   * <!-- begin-user-doc -->
+   * <!-- end-user-doc -->
+   * @generated
+   */
+  public boolean isSetOpposite()
+  {
+    return opposite_set_;
   }
 
   /**
@@ -741,7 +932,7 @@
   {
     if (anyAttribute == null)
     {
-      anyAttribute = createSequence(ANY_ATTRIBUTE);
+      anyAttribute = createSequence(INTERNAL_ANY_ATTRIBUTE);
     }
     return anyAttribute;
   }
@@ -866,7 +1057,7 @@
         unsetSequence(getAny());
         return;
       case NAME:
-        setName(NAME_DEFAULT_);
+        unsetName();
         return;
       case MANY:
         unsetMany();
@@ -875,16 +1066,16 @@
         unsetContainment();
         return;
       case DEFAULT:
-        setDefault_(DEFAULT_DEFAULT_);
+        unsetDefault();
         return;
       case READ_ONLY:
         unsetReadOnly();
         return;
       case TYPE:
-        setType((Type)null);
+        unsetType();
         return;
       case OPPOSITE:
-        setOpposite_((Property)null);
+        unsetOpposite();
         return;
       case NULLABLE:
         unsetNullable();
@@ -910,19 +1101,19 @@
       case ANY:
         return any != null && !isSequenceEmpty(getAny());
       case NAME:
-        return NAME_DEFAULT_ == null ? name != null : !NAME_DEFAULT_.equals(name);
+        return isSetName();
       case MANY:
         return isSetMany();
       case CONTAINMENT:
         return isSetContainment();
       case DEFAULT:
-        return DEFAULT_DEFAULT_ == null ? default_ != null : !DEFAULT_DEFAULT_.equals(default_);
+        return isSetDefault();
       case READ_ONLY:
         return isSetReadOnly();
       case TYPE:
-        return type != null;
+        return isSetType();
       case OPPOSITE:
-        return opposite != null;
+        return isSetOpposite();
       case NULLABLE:
         return isSetNullable();
       case ANY_ATTRIBUTE:
@@ -946,13 +1137,13 @@
     result.append(", any: ");
     result.append(any);
     result.append(", name: ");
-    result.append(name);
+    if (name_set_) result.append(name); else result.append("<unset>");
     result.append(", many: ");
     if (many_set_) result.append(many); else result.append("<unset>");
     result.append(", containment: ");
     if (containment_set_) result.append(containment); else result.append("<unset>");
     result.append(", default: ");
-    result.append(default_);
+    if (default_set_) result.append(default_); else result.append("<unset>");
     result.append(", readOnly: ");
     if (readOnly_set_) result.append(readOnly); else result.append("<unset>");
     result.append(", nullable: ");

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/TextTypeImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/TextTypeImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataGraphTypeImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataGraphTypeImpl.java Wed Feb 28 16:33:41 2007
@@ -27,60 +27,81 @@
  */
 public class DataGraphTypeImpl extends BaseDataGraphTypeImpl implements DataGraphType
 {
+
+  public final static int ANY = BaseDataGraphTypeImpl.SDO_PROPERTY_COUNT + -1;
+
+  public final static int SDO_PROPERTY_COUNT = BaseDataGraphTypeImpl.SDO_PROPERTY_COUNT + 0;
+
+  public final static int EXTENDED_PROPERTY_COUNT = BaseDataGraphTypeImpl.EXTENDED_PROPERTY_COUNT - 1;
+
+
   /**
    * The feature id for the '<em><b>Models</b></em>' containment reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int MODELS = BaseDataGraphTypeImpl.MODELS;
+   */ 
+  public final static int INTERNAL_MODELS = BaseDataGraphTypeImpl.MODELS;
 
   /**
    * The feature id for the '<em><b>Xsd</b></em>' containment reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int XSD = BaseDataGraphTypeImpl.XSD;
+   */ 
+  public final static int INTERNAL_XSD = BaseDataGraphTypeImpl.XSD;
 
   /**
    * The feature id for the '<em><b>Change Summary</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int CHANGE_SUMMARY = BaseDataGraphTypeImpl.CHANGE_SUMMARY;
+   */ 
+  public final static int INTERNAL_CHANGE_SUMMARY = BaseDataGraphTypeImpl.CHANGE_SUMMARY;
 
   /**
    * The feature id for the '<em><b>Any Attribute</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int ANY_ATTRIBUTE = BaseDataGraphTypeImpl.ANY_ATTRIBUTE;
+   */ 
+  public final static int INTERNAL_ANY_ATTRIBUTE = BaseDataGraphTypeImpl.ANY_ATTRIBUTE;
 
   /**
    * The feature id for the '<em><b>Any</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int ANY = BaseDataGraphTypeImpl.SDO_PROPERTY_COUNT + 0;
+   */ 
+  public final static int INTERNAL_ANY = BaseDataGraphTypeImpl.INTERNAL_PROPERTY_COUNT + 0;
 
   /**
-   * This represents the number of properties for this type.
+   * The number of properties for this type.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
    */
-  
-  public final static int SDO_PROPERTY_COUNT = BaseDataGraphTypeImpl.SDO_PROPERTY_COUNT + 1;
+  public final static int INTERNAL_PROPERTY_COUNT = BaseDataGraphTypeImpl.INTERNAL_PROPERTY_COUNT + 1;
+
+  protected int internalConvertIndex(int internalIndex)
+  {
+    switch (internalIndex)
+    {
+      case INTERNAL_MODELS: return MODELS;
+      case INTERNAL_XSD: return XSD;
+      case INTERNAL_CHANGE_SUMMARY: return CHANGE_SUMMARY;
+      case INTERNAL_ANY_ATTRIBUTE: return ANY_ATTRIBUTE;
+      case INTERNAL_ANY: return ANY;
+    }
+    return super.internalConvertIndex(internalIndex);
+  }
+
 
   /**
    * The cached value of the '{@link #getAny() <em>Any</em>}' attribute list.
@@ -122,7 +143,7 @@
   {
     if (any == null)
     {
-      any = createSequence(ANY);
+      any = createSequence(INTERNAL_ANY);
     }
     return any;
   }
@@ -27,60 +27,81 @@
   /**
-   * The feature id for the '<em><b>Models</b></em>' containment reference.
+   * The internal feature id for the '<em><b>Models</b></em>' containment reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -27,60 +27,81 @@
 
   /**
-   * The feature id for the '<em><b>Xsd</b></em>' containment reference.
+   * The internal feature id for the '<em><b>Xsd</b></em>' containment reference.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -27,60 +27,81 @@
 
   /**
-   * The feature id for the '<em><b>Change Summary</b></em>' attribute.
+   * The internal feature id for the '<em><b>Change Summary</b></em>' attribute.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -27,60 +27,81 @@
 
   /**
-   * The feature id for the '<em><b>Any Attribute</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Any Attribute</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
@@ -27,60 +27,81 @@
 
   /**
-   * The feature id for the '<em><b>Any</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Any</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataObjectImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/DataObjectImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelsTypeImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/ModelsTypeImpl.java Wed Feb 28 16:33:41 2007
@@ -29,24 +29,41 @@
  */
 public class ModelsTypeImpl extends DataObjectBase implements ModelsType
 {
+
+  public final static int ANY = -1;
+
+  public final static int SDO_PROPERTY_COUNT = 0;
+
+  public final static int EXTENDED_PROPERTY_COUNT = -1;
+
+
   /**
    * The feature id for the '<em><b>Any</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int ANY = 0;
+   */ 
+  public final static int INTERNAL_ANY = 0;
 
   /**
-   * This represents the number of properties for this type.
+   * The number of properties for this type.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
    */
-  
-  public final static int SDO_PROPERTY_COUNT = 1;
+  public final static int INTERNAL_PROPERTY_COUNT = 1;
+
+  protected int internalConvertIndex(int internalIndex)
+  {
+    switch (internalIndex)
+    {
+      case INTERNAL_ANY: return ANY;
+    }
+    return super.internalConvertIndex(internalIndex);
+  }
+
 
   /**
    * The cached value of the '{@link #getAny() <em>Any</em>}' attribute list.
@@ -88,7 +105,7 @@
   {
     if (any == null)
     {
-      any = createSequence(ANY);
+      any = createSequence(INTERNAL_ANY);
     }
     return any;
   }
@@ -29,24 +29,41 @@
   /**
-   * The feature id for the '<em><b>Any</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Any</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->

Modified: incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/PropertyImpl.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/PropertyImpl.java?view=diff&rev=513084&r1=513083&r2=513084
==============================================================================
--- incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/TextTypeImpl.java (original)
+++ incubator/tuscany/java/sdo/impl/src/main/java/org/apache/tuscany/sdo/model/impl/TextTypeImpl.java Wed Feb 28 16:33:41 2007
@@ -31,24 +31,41 @@
  */
 public abstract class TextTypeImpl extends DataObjectBase implements TextType
 {
+
+  public final static int TEXT = 0;
+
+  public final static int SDO_PROPERTY_COUNT = 1;
+
+  public final static int EXTENDED_PROPERTY_COUNT = 0;
+
+
   /**
    * The feature id for the '<em><b>Text</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
-   */	 
-  public final static int TEXT = 0;
+   */ 
+  public final static int INTERNAL_TEXT = 0;
 
   /**
-   * This represents the number of properties for this type.
+   * The number of properties for this type.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
    * @generated
    * @ordered
    */
-  
-  public final static int SDO_PROPERTY_COUNT = 1;
+  public final static int INTERNAL_PROPERTY_COUNT = 1;
+
+  protected int internalConvertIndex(int internalIndex)
+  {
+    switch (internalIndex)
+    {
+      case INTERNAL_TEXT: return TEXT;
+    }
+    return super.internalConvertIndex(internalIndex);
+  }
+
 
   /**
    * The cached value of the '{@link #getText() <em>Text</em>}' attribute list.



---------------------------------------------------------------------
@@ -31,24 +31,41 @@
   /**
-   * The feature id for the '<em><b>Text</b></em>' attribute list.
+   * The internal feature id for the '<em><b>Text</b></em>' attribute list.
    * <!-- begin-user-doc -->
    * <!-- end-user-doc -->
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org